from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, Int, Float, String, Directory, Boolean

Metaprosip_V0_1_0 = CommandToolBuilder(tool="MetaProSIP", base_command=["MetaProSIP"], inputs=[ToolInput(tag="in_in_mzm_l", input_type=File(optional=True), prefix="-in_mzML", doc=InputDocumentation(doc="*                  Centroided MS1 data (valid formats: 'mzML')")), ToolInput(tag="in_in_fast_a", input_type=File(optional=True), prefix="-in_fasta", doc=InputDocumentation(doc="*                 Protein sequence database (valid formats: 'fasta')")), ToolInput(tag="in_out_csv", input_type=File(optional=True), prefix="-out_csv", doc=InputDocumentation(doc="*                  Column separated file with feature fitting result. (valid formats: 'csv')")), ToolInput(tag="in_out_peptide_centric_csv", input_type=File(optional=True), prefix="-out_peptide_centric_csv", doc=InputDocumentation(doc="*  Column separated file with peptide centric result. (valid formats: 'csv')")), ToolInput(tag="in_in_feature_xml", input_type=File(optional=True), prefix="-in_featureXML", doc=InputDocumentation(doc="*            Feature data annotated with identifications (IDMapper) (valid formats: 'featureXML')")), ToolInput(tag="in_r_executable", input_type=File(optional=True), prefix="-r_executable", doc=InputDocumentation(doc="Path to the R executable (default: 'R')")), ToolInput(tag="in_mz_tolerance_ppm", input_type=Int(optional=True), prefix="-mz_tolerance_ppm", doc=InputDocumentation(doc="Tolerance in ppm (default: '10')")), ToolInput(tag="in_rt_tolerance_s", input_type=Int(optional=True), prefix="-rt_tolerance_s", doc=InputDocumentation(doc="Rolerance window around feature rt for XIC extraction (default: '30')")), ToolInput(tag="in_intensity_threshold", input_type=Int(optional=True), prefix="-intensity_threshold", doc=InputDocumentation(doc="Intensity threshold to collect peaks in the MS1 spectrum. (default: '10')")), ToolInput(tag="in_correlation_threshold", input_type=Float(optional=True), prefix="-correlation_threshold", doc=InputDocumentation(doc="Correlation threshold for reporting a RIA (default: '0.7')")), ToolInput(tag="in_xic_threshold", input_type=File(optional=True), prefix="-xic_threshold", doc=InputDocumentation(doc="Minimum correlation to mono-isotopic peak for retaining a higher isotopic peak. If featureXML from reference file is used it should be disabled (set to -1) as no mono-isotopic peak is expected to be present. (default: '0.7')")), ToolInput(tag="in_decomposition_threshold", input_type=Float(optional=True), prefix="-decomposition_threshold", doc=InputDocumentation(doc="Minimum R-squared of decomposition that must be achieved for a peptide to be reported. (default: '0.7')")), ToolInput(tag="in_weight_merge_window", input_type=Int(optional=True), prefix="-weight_merge_window", doc=InputDocumentation(doc="Decomposition coefficients within +- this rate window will be combined (default: '5')")), ToolInput(tag="in_plot_extension", input_type=String(optional=True), prefix="-plot_extension", doc=InputDocumentation(doc="Extension used for plots (png|svg|pdf). (default: 'png' valid: 'png', 'svg', 'pdf')")), ToolInput(tag="in_qc_output_directory", input_type=Directory(optional=True), prefix="-qc_output_directory", doc=InputDocumentation(doc="Output directory for the quality report")), ToolInput(tag="in_labeling_element", input_type=String(optional=True), prefix="-labeling_element", doc=InputDocumentation(doc="Which element (single letter code) is labeled. (default: 'C' valid: 'C', 'N', 'H', 'O')")), ToolInput(tag="in_use_unassigned_ids", input_type=Boolean(optional=True), prefix="-use_unassigned_ids", doc=InputDocumentation(doc="Include identifications not assigned to a feature in pattern detection.")), ToolInput(tag="in_use_averag_in_e_ids", input_type=Boolean(optional=True), prefix="-use_averagine_ids", doc=InputDocumentation(doc="Use averagine peptides as model to perform pattern detection on unidentified peptides.")), ToolInput(tag="in_report_natural_peptides", input_type=Boolean(optional=True), prefix="-report_natural_peptides", doc=InputDocumentation(doc="Whether purely natural peptides are reported in the quality report.")), ToolInput(tag="in_filter_mono_isotopic", input_type=Boolean(optional=True), prefix="-filter_monoisotopic", doc=InputDocumentation(doc="Try to filter out mono-isotopic patterns to improve detection of low RIA patterns")), ToolInput(tag="in_cluster", input_type=Boolean(optional=True), prefix="-cluster", doc=InputDocumentation(doc="Perform grouping")), ToolInput(tag="in_ini", input_type=File(optional=True), prefix="-ini", doc=InputDocumentation(doc="Use the given TOPP INI file")), ToolInput(tag="in_threads", input_type=Int(optional=True), prefix="-threads", doc=InputDocumentation(doc="Sets the number of threads allowed to be used by the TOPP tool (default: '1')")), ToolInput(tag="in_write_ini", input_type=File(optional=True), prefix="-write_ini", doc=InputDocumentation(doc="Writes the default configuration file")), ToolInput(tag="in_helphelp", input_type=Boolean(optional=True), prefix="--helphelp", doc=InputDocumentation(doc="Shows all options (including advanced)"))], outputs=[ToolOutput(tag="out_qc_output_directory", output_type=Directory(optional=True), selector=InputSelector(input_to_select="in_qc_output_directory", type_hint=File()), doc=OutputDocumentation(doc="Output directory for the quality report"))], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Metaprosip_V0_1_0().translate("wdl", allow_empty_container=True)

